USE master
GO
IF EXISTS ( SELECT name FROM sysdatabases WHERE name ='DPS')
   BEGIN
     DROP DATABASE DPS
   END
GO
CREATE DATABASE DPS 
GO
exec sp_dboption 'DPS','select into/bulkcopy','true'
execute sp_dboption 'DPS', 'autoshrink', true
GO
USE DPS
GO
CREATE TABLE Groups
   (
    gId tinyint NOT NULL CONSTRAINT PK_Groups_gId PRIMARY KEY CHECK(gId BETWEEN 0 AND 9),
    Name varchar(64) COLLATE SQL_Croatian_CP1250_CS_AS
   )
GO
CREATE TABLE Indicators
   (
    gId tinyint NOT NULL CONSTRAINT FK_Indicators_gId FOREIGN KEY REFERENCES Groups(gId) ON DELETE CASCADE ON UPDATE CASCADE,
    Id  smallint NOT NULL UNIQUE CLUSTERED CHECK(Id BETWEEN 0 AND 9999),
    pId smallint CONSTRAINT FK_Indicators_pId FOREIGN KEY REFERENCES Indicators(Id),
    Title varchar(128) COLLATE SQL_Croatian_CP1250_CS_AS
   )
GO
CREATE TABLE Regions
   (
    Code smallint NOT NULL CONSTRAINT PK_Regions_Code PRIMARY KEY CHECK(Code BETWEEN 10000 AND 19900),
    rNum tinyint  NOT NULL,
    rMapNum tinyint NOT NULL,
    pCode smallint CONSTRAINT FK_Regions_pCode FOREIGN KEY REFERENCES Regions(Code),
    rId varchar(4) COLLATE SQL_Croatian_CP1250_CS_AS,
    Title varchar(64) COLLATE SQL_Croatian_CP1250_CS_AS,
    CONSTRAINT CK_Regions_rMapNum CHECK(rMapNum <=rNum)
   )
GO
CREATE TABLE Counties
   (
    rCode smallint NOT NULL CONSTRAINT FK_Counties_Code FOREIGN KEY REFERENCES Regions(Code) ON DELETE CASCADE ON UPDATE CASCADE,
    cCode tinyint  NOT NULL,
    Id    varchar(16) UNIQUE,
    Name varchar(64) COLLATE SQL_Croatian_CP1250_CS_AS,
    CONSTRAINT U_Counties_rCodecCode UNIQUE CLUSTERED (rCode,cCode)
   )
GO
CREATE TABLE Definitions
   (
    Id smallint NOT NULL  CONSTRAINT FK_Definitions_Ind  FOREIGN KEY REFERENCES Indicators(Id) ON DELETE CASCADE ON UPDATE CASCADE,
    Name text COLLATE SQL_Croatian_CP1250_CS_AS
   )
GO
CREATE TABLE Titles
   (
    Id int PRIMARY KEY,
    Title text COLLATE SQL_Croatian_CP1250_CS_AS NOT NULL
   )
GO
CREATE TABLE Langs
   (
    Id varchar(16) PRIMARY KEY,
    Title varbinary(32) NOT NULL,
    CodePage varchar(32) NOT NULL,
    mbCS varchar(32) NOT NULL,
    connCS varchar(32) NOT NULL,
    def tinyint NOT NULL DEFAULT 0
   )
GO
CREATE TABLE TimePoints
   (
    tpId smallint NOT NULL UNIQUE CLUSTERED DEFAULT YEAR(GETDATE()),
    tpTitle varchar(16)
   )
GO
CREATE TABLE Data
   (
    tpId smallint NOT NULL CONSTRAINT FK_Data_tpId FOREIGN KEY REFERENCES TimePoints(tpId) ON DELETE CASCADE ON UPDATE CASCADE,
    Ind  smallint NOT NULL CONSTRAINT FK_Data_Ind  FOREIGN KEY REFERENCES Indicators(Id) ON DELETE CASCADE ON UPDATE CASCADE,
    rCode smallint NOT NULL,
    cCode tinyint NOT NULL,
    val float(53) NOT NULL DEFAULT -100000000,
    CONSTRAINT FK_Data_rCodecCode FOREIGN KEY (rCode,cCode) REFERENCES Counties(rCode,cCode) ON DELETE CASCADE ON UPDATE CASCADE,
    CONSTRAINT U_Data_yIdIndrCodecCode UNIQUE CLUSTERED (tpId,Ind,rCode,cCode)
   )
GO
CREATE TABLE Maps
   (
    mCode smallint NOT NULL UNIQUE,
    mSize int NOT NULL,
    mData image
   )
GO
DECLARE tables_cursor CURSOR
   FOR
   SELECT name FROM sysobjects WHERE type = 'U'
OPEN tables_cursor
DECLARE @tablename sysname
FETCH NEXT FROM tables_cursor INTO @tablename
WHILE (@@FETCH_STATUS <> -1)
BEGIN
   EXEC('GRANT SELECT ON '+@tablename+' TO PUBLIC')
   FETCH NEXT FROM tables_cursor INTO @tablename
END
DEALLOCATE tables_cursor
GO