DROP DATABASE IF EXISTS DPS;

CREATE DATABASE DPS;
USE DPS;

CREATE TABLE Groups
   (
    gId  TINYINT  NOT NULL,
    Name VARCHAR(64),
    CONSTRAINT PK_Groups_gId PRIMARY KEY (gId)
   )ENGINE=InnoDB DEFAULT CHARACTER SET cp1250 COLLATE cp1250_general_ci;

CREATE TABLE Indicators
   (
    gId   TINYINT NOT NULL,
    Id    SMALLINT NOT NULL UNIQUE,
    pId   SMALLINT DEFAULT NULL,
    Title VARCHAR(128),
    CONSTRAINT PK_Indicators_Id  PRIMARY KEY (Id),
    INDEX I_Indicators_gId (gId),
    CONSTRAINT FK_Indicators_gId FOREIGN KEY (gId) REFERENCES Groups(gId)
   )ENGINE=InnoDB DEFAULT CHARACTER SET cp1250 COLLATE cp1250_general_ci;

CREATE TABLE Regions
   (
    Code SMALLINT NOT NULL,
    rNum TINYINT  NOT NULL,
    rMapNum TINYINT NOT NULL,
    pCode SMALLINT,
    rId VARCHAR(4),
    Title VARCHAR(64),
    CONSTRAINT PK_Regions_Code PRIMARY KEY (Code)
   )ENGINE=InnoDB DEFAULT CHARACTER SET cp1250 COLLATE cp1250_general_ci;

CREATE TABLE Counties
   (
    rCode SMALLINT NOT NULL,
    cCode TINYINT  NOT NULL,
    Id    VARCHAR(16) UNIQUE,
    Name  VARCHAR(64),
    CONSTRAINT U_Counties_rCodecCode UNIQUE (rCode,cCode),
    CONSTRAINT FK_Counties_Code FOREIGN KEY (rCode) REFERENCES Regions(Code)
   )ENGINE=InnoDB DEFAULT CHARACTER SET cp1250 COLLATE cp1250_general_ci;

CREATE TABLE Definitions
   (
    Id SMALLINT NOT NULL UNIQUE,
    Name TEXT,
    CONSTRAINT FK_Definitions_Ind  FOREIGN KEY (Id) REFERENCES Indicators(Id)
   )ENGINE=InnoDB DEFAULT CHARACTER SET cp1250 COLLATE cp1250_general_ci;

CREATE TABLE Titles
   (
    Id INT NOT NULL UNIQUE,
    Title TEXT NOT NULL,
    CONSTRAINT PK_Titles_Id PRIMARY KEY (Id)
   )ENGINE=InnoDB DEFAULT CHARACTER SET cp1250 COLLATE cp1250_general_ci;

CREATE TABLE Langs
   (
    Id VARCHAR(16),
    Title VARBINARY(32) NOT NULL,
    CodePage VARCHAR(32) NOT NULL,
    mbCS VARCHAR(32) NOT NULL,
    connCS VARCHAR(32) NOT NULL,
    def TINYINT NOT NULL DEFAULT 0,
    CONSTRAINT PK_Langs_Id PRIMARY KEY (Id)
   )ENGINE=InnoDB;

CREATE TABLE TimePoints
   (
    tpId SMALLINT NOT NULL UNIQUE,
    tpTitle VARCHAR(16)
   )ENGINE=InnoDB;

CREATE TABLE Data
   (
    tpId  SMALLINT NOT NULL,
    Ind   SMALLINT NOT NULL,
    rCode SMALLINT NOT NULL,
    cCode TINYINT NOT NULL,
    val   FLOAT(53) NOT NULL DEFAULT -100000000,
    INDEX I_Data_tpId (tpId),
    INDEX I_Data_Ind (Ind),
    INDEX I_Data_rCodecCode (rCode,cCode),
    CONSTRAINT PK_Data_yIdIndrCodecCode PRIMARY KEY (tpId,Ind,rCode,cCode),
    CONSTRAINT FK_Data_tpId FOREIGN KEY (tpId) REFERENCES TimePoints(tpId),
    CONSTRAINT FK_Data_Ind  FOREIGN KEY (Ind)  REFERENCES Indicators(Id),
    CONSTRAINT FK_Data_rCodecCode FOREIGN KEY (rCode,cCode) REFERENCES Counties(rCode,cCode)
   )ENGINE=InnoDB;

CREATE TABLE Maps
   (
    mCode SMALLINT NOT NULL UNIQUE,
    mSize INT NOT NULL,
    mData MEDIUMBLOB
   )ENGINE=InnoDB;

